@@ -31,8 +31,8 @@
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
-static SetupTest *setup = 0;
-static TestRunner *runner = 0;
+static SetupTest *setup = nullptr;
+static TestRunner *runner = nullptr;
 
 void sigHandler(int signal)
 {
@@ -124,7 +124,7 @@ int main(int argc, char **argv)
     }
 
     delete setup;
-    setup = 0;
+    setup = nullptr;
 
     return exitCode;
 }
