@@ -263,14 +263,17 @@ void SetupTest::shutdown()
         qDebug() << "Shutting down Akonadi control...";
         Akonadi::ServerManager::self()->stop();
         // safety timeout
-        QTimer::singleShot(30 * 1000, this, SLOT(shutdownHarder()));
+        QTimer::singleShot(30 * 1000, this, &SetupTest::shutdownHarder);
         break;
     case Akonadi::ServerManager::NotRunning:
     case Akonadi::ServerManager::Broken:
         shutdownHarder();
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
     case Akonadi::ServerManager::Stopping:
         // safety timeout
-        QTimer::singleShot(30 * 1000, this, SLOT(shutdownHarder()));
+        QTimer::singleShot(30 * 1000, this, &SetupTest::shutdownHarder);
         break;
     }
 }
