@@ -44,7 +44,7 @@ public:
     bool isScenarioDone() const;
 
 protected:
-    void run() Q_DECL_OVERRIDE;
+    void run() override;
 
 private Q_SLOTS:
     void dataAvailable();
