@@ -36,7 +36,6 @@
 #include "statusadaptor.h"
 #include "private/standarddirs_p.h"
 
-
 #include "akonadiagentbase_debug.h"
 
 #include <KLocalizedString>
@@ -44,7 +43,6 @@
 
 #include <Kdelibs4ConfigMigrator>
 
-#include <QDir>
 #include <QSettings>
 #include <QTimer>
 #include <QDBusConnection>
@@ -62,7 +60,7 @@
 
 using namespace Akonadi;
 
-static AgentBase *sAgentBase = 0;
+static AgentBase *sAgentBase = nullptr;
 
 AgentBase::Observer::Observer()
 {
@@ -76,7 +74,7 @@ void AgentBase::Observer::itemAdded(const Item &item, const Collection &collecti
 {
     Q_UNUSED(item);
     Q_UNUSED(collection);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -85,7 +83,7 @@ void AgentBase::Observer::itemChanged(const Item &item, const QSet<QByteArray> &
 {
     Q_UNUSED(item);
     Q_UNUSED(partIdentifiers);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -93,7 +91,7 @@ void AgentBase::Observer::itemChanged(const Item &item, const QSet<QByteArray> &
 void AgentBase::Observer::itemRemoved(const Item &item)
 {
     Q_UNUSED(item);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -102,7 +100,7 @@ void AgentBase::Observer::collectionAdded(const Akonadi::Collection &collection,
 {
     Q_UNUSED(collection);
     Q_UNUSED(parent);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -110,7 +108,7 @@ void AgentBase::Observer::collectionAdded(const Akonadi::Collection &collection,
 void AgentBase::Observer::collectionChanged(const Collection &collection)
 {
     Q_UNUSED(collection);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -118,7 +116,7 @@ void AgentBase::Observer::collectionChanged(const Collection &collection)
 void AgentBase::Observer::collectionRemoved(const Collection &collection)
 {
     Q_UNUSED(collection);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -128,7 +126,7 @@ void AgentBase::ObserverV2::itemMoved(const Akonadi::Item &item, const Akonadi::
     Q_UNUSED(item);
     Q_UNUSED(source);
     Q_UNUSED(dest);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -137,7 +135,7 @@ void AgentBase::ObserverV2::itemLinked(const Akonadi::Item &item, const Akonadi:
 {
     Q_UNUSED(item);
     Q_UNUSED(collection);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemLinked,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemLinked);
@@ -149,7 +147,7 @@ void AgentBase::ObserverV2::itemUnlinked(const Akonadi::Item &item, const Akonad
 {
     Q_UNUSED(item);
     Q_UNUSED(collection);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemUnlinked,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemUnlinked);
@@ -162,7 +160,7 @@ void AgentBase::ObserverV2::collectionMoved(const Akonadi::Collection &collectio
     Q_UNUSED(collection);
     Q_UNUSED(source);
     Q_UNUSED(dest);
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         sAgentBase->d_ptr->changeProcessed();
     }
 }
@@ -173,13 +171,13 @@ void AgentBase::ObserverV2::collectionChanged(const Akonadi::Collection &collect
     collectionChanged(collection);
 }
 
-void AgentBase::ObserverV3::itemsFlagsChanged(const Akonadi::Item::List &items, const QSet< QByteArray > &addedFlags, const QSet< QByteArray > &removedFlags)
+void AgentBase::ObserverV3::itemsFlagsChanged(const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags)
 {
     Q_UNUSED(items);
     Q_UNUSED(addedFlags);
     Q_UNUSED(removedFlags);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsFlagsChanged,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemsFlagsChanged);
@@ -193,7 +191,7 @@ void AgentBase::ObserverV3::itemsMoved(const Akonadi::Item::List &items, const C
     Q_UNUSED(sourceCollection);
     Q_UNUSED(destinationCollection);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsMoved,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemsMoved);
@@ -205,7 +203,7 @@ void AgentBase::ObserverV3::itemsRemoved(const Akonadi::Item::List &items)
 {
     Q_UNUSED(items);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsRemoved,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemsRemoved);
@@ -218,7 +216,7 @@ void AgentBase::ObserverV3::itemsLinked(const Akonadi::Item::List &items, const
     Q_UNUSED(items);
     Q_UNUSED(collection);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsLinked,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemsLinked);
@@ -231,7 +229,7 @@ void AgentBase::ObserverV3::itemsUnlinked(const Akonadi::Item::List &items, cons
     Q_UNUSED(items);
     Q_UNUSED(collection)
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimizations in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsUnlinked,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemsUnlinked);
@@ -243,7 +241,7 @@ void AgentBase::ObserverV4::tagAdded(const Tag &tag)
 {
     Q_UNUSED(tag);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::tagAdded,
                             sAgentBase->d_ptr, &AgentBasePrivate::tagAdded);
@@ -255,7 +253,7 @@ void AgentBase::ObserverV4::tagChanged(const Tag &tag)
 {
     Q_UNUSED(tag);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::tagChanged,
                             sAgentBase->d_ptr, &AgentBasePrivate::tagChanged);
@@ -267,7 +265,7 @@ void AgentBase::ObserverV4::tagRemoved(const Tag &tag)
 {
     Q_UNUSED(tag);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::tagRemoved,
                             sAgentBase->d_ptr, &AgentBasePrivate::tagRemoved);
@@ -281,7 +279,7 @@ void AgentBase::ObserverV4::itemsTagsChanged(const Item::List &items, const QSet
     Q_UNUSED(addedTags);
     Q_UNUSED(removedTags);
 
-    if (sAgentBase != 0) {
+    if (sAgentBase) {
         // not implementation, let's disconnect the signal to enable optimization in Monitor
         QObject::disconnect(sAgentBase->changeRecorder(), &Monitor::itemsTagsChanged,
                             sAgentBase->d_ptr, &AgentBasePrivate::itemsTagsChanged);
@@ -338,21 +336,21 @@ AgentBasePrivate::AgentBasePrivate(AgentBase *parent)
     , mNeedsNetwork(false)
     , mOnline(false)
     , mDesiredOnlineState(false)
-    , mSettings(0)
-    , mChangeRecorder(0)
-    , mTracer(0)
-    , mObserver(0)
-    , mPowerInterface(0)
-    , mTemporaryOfflineTimer(0)
-    , mEventLoopLocker(0)
-    , mNetworkManager(Q_NULLPTR)
+    , mSettings(nullptr)
+    , mChangeRecorder(nullptr)
+    , mTracer(nullptr)
+    , mObserver(nullptr)
+    , mPowerInterface(nullptr)
+    , mTemporaryOfflineTimer(nullptr)
+    , mEventLoopLocker(nullptr)
+    , mNetworkManager(nullptr)
 {
     Internal::setClientType(Internal::Agent);
 }
 
 AgentBasePrivate::~AgentBasePrivate()
 {
-    mChangeRecorder->setConfig(0);
+    mChangeRecorder->setConfig(nullptr);
     delete mSettings;
 }
 
@@ -434,7 +432,7 @@ void AgentBasePrivate::init()
                 q, SLOT(slotResumedFromSuspend()));
     } else {
         delete mPowerInterface;
-        mPowerInterface = 0;
+        mPowerInterface = nullptr;
     }
 
     // Use reference counting to allow agents to finish internal jobs when the
@@ -466,7 +464,7 @@ void AgentBasePrivate::setProgramName()
     // ugly, really ugly, if you find another solution, change it and blame me for this code (Andras)
     QString programName = mResourceTypeName;
     if (!mName.isEmpty()) {
-        programName = i18nc("Name and type of Akonadi resource", "%1 of type %2", mName, mResourceTypeName) ;
+        programName = i18nc("Name and type of Akonadi resource", "%1 of type %2", mName, mResourceTypeName);
     }
 
     QGuiApplication::setApplicationDisplayName(programName);
@@ -474,14 +472,14 @@ void AgentBasePrivate::setProgramName()
 
 void AgentBasePrivate::itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection)
 {
-    if (mObserver != 0) {
+    if (mObserver) {
         mObserver->itemAdded(item, collection);
     }
 }
 
 void AgentBasePrivate::itemChanged(const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers)
 {
-    if (mObserver != 0) {
+    if (mObserver) {
         mObserver->itemChanged(item, partIdentifiers);
     }
 }
@@ -523,7 +521,7 @@ void AgentBasePrivate::itemMoved(const Akonadi::Item &item, const Akonadi::Colle
 
 void AgentBasePrivate::itemRemoved(const Akonadi::Item &item)
 {
-    if (mObserver != 0) {
+    if (mObserver) {
         mObserver->itemRemoved(item);
     }
 }
@@ -709,7 +707,7 @@ void AgentBasePrivate::itemsRelationsChanged(const Akonadi::Item::List &items,
 
 void AgentBasePrivate::collectionAdded(const Akonadi::Collection &collection, const Akonadi::Collection &parent)
 {
-    if (mObserver != 0) {
+    if (mObserver) {
         mObserver->collectionAdded(collection, parent);
     }
 }
@@ -717,7 +715,7 @@ void AgentBasePrivate::collectionAdded(const Akonadi::Collection &collection, co
 void AgentBasePrivate::collectionChanged(const Akonadi::Collection &collection)
 {
     AgentBase::ObserverV2 *observer2 = dynamic_cast<AgentBase::ObserverV2 *>(mObserver);
-    if (mObserver != 0 && observer2 == 0) {   // For ObserverV2 we use the variant with the part identifiers
+    if (mObserver && observer2 == nullptr) {   // For ObserverV2 we use the variant with the part identifiers
         mObserver->collectionChanged(collection);
     }
 }
@@ -725,7 +723,7 @@ void AgentBasePrivate::collectionChanged(const Akonadi::Collection &collection)
 void AgentBasePrivate::collectionChanged(const Akonadi::Collection &collection, const QSet<QByteArray> &changedAttributes)
 {
     AgentBase::ObserverV2 *observer2 = dynamic_cast<AgentBase::ObserverV2 *>(mObserver);
-    if (observer2 != 0) {
+    if (observer2) {
         observer2->collectionChanged(collection, changedAttributes);
     }
 }
@@ -747,7 +745,7 @@ void AgentBasePrivate::collectionMoved(const Akonadi::Collection &collection, co
 
 void AgentBasePrivate::collectionRemoved(const Akonadi::Collection &collection)
 {
-    if (mObserver != 0) {
+    if (mObserver) {
         mObserver->collectionRemoved(collection);
     }
 }
@@ -1008,6 +1006,7 @@ void AgentBase::setNeedsNetwork(bool needsNetwork)
 
     } else {
         delete d->mNetworkManager;
+        d->mNetworkManager = nullptr;
         setOnlineInternal(d->mDesiredOnlineState);
     }
 }
@@ -1108,12 +1107,12 @@ void AgentBase::quit()
     aboutToQuit();
 
     if (d->mSettings) {
-        d->mChangeRecorder->setConfig(0);
+        d->mChangeRecorder->setConfig(nullptr);
         d->mSettings->sync();
     }
 
     delete d->mEventLoopLocker;
-    d->mEventLoopLocker = Q_NULLPTR;
+    d->mEventLoopLocker = nullptr;
 }
 
 void AgentBase::aboutToQuit()
@@ -1134,28 +1133,35 @@ void AgentBase::cleanup()
     /*
      * First destroy the settings object...
      */
-    d->mChangeRecorder->setConfig(0);
+    d->mChangeRecorder->setConfig(nullptr);
     delete d->mSettings;
-    d->mSettings = 0;
+    d->mSettings = nullptr;
 
     /*
      * ... then remove the file from hd.
      */
-    QFile::remove(fileName);
+    if (!QFile::remove(fileName)) {
+        qCWarning(AKONADIAGENTBASE_LOG) << "Impossible to remove " << fileName;
+    }
 
     /*
      * ... and remove the changes file from hd.
      */
-    QFile::remove(fileName + QStringLiteral("_changes.dat"));
+    const QString changeDataFileName = fileName + QStringLiteral("_changes.dat");
+    if (!QFile::remove(changeDataFileName)) {
+        qCWarning(AKONADIAGENTBASE_LOG) << "Impossible to remove " << changeDataFileName;
+    }
 
     /*
      * ... and also remove the agent configuration file if there is one.
      */
-    QString configFile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + config()->name();
-    QFile::remove(configFile);
+    const QString configFile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + config()->name();
+    if (!QFile::remove(configFile)) {
+        qCWarning(AKONADIAGENTBASE_LOG) << "Impossible to remove config file " << configFile;
+    }
 
     delete d->mEventLoopLocker;
-    d->mEventLoopLocker = Q_NULLPTR;
+    d->mEventLoopLocker = nullptr;
 }
 
 void AgentBase::registerObserver(Observer *observer)
@@ -1163,8 +1169,8 @@ void AgentBase::registerObserver(Observer *observer)
     // TODO in theory we should re-connect change recorder signals here that we disconnected previously
     d_ptr->mObserver = observer;
 
-    const bool hasObserverV3 = (dynamic_cast<AgentBase::ObserverV3 *>(d_ptr->mObserver) != 0);
-    const bool hasObserverV4 = (dynamic_cast<AgentBase::ObserverV4 *>(d_ptr->mObserver) != 0);
+    const bool hasObserverV3 = (dynamic_cast<AgentBase::ObserverV3 *>(d_ptr->mObserver) != nullptr);
+    const bool hasObserverV4 = (dynamic_cast<AgentBase::ObserverV4 *>(d_ptr->mObserver) != nullptr);
 
     disconnect(d_ptr->mChangeRecorder, &Monitor::tagAdded,
                d_ptr, &AgentBasePrivate::tagAdded);
