@@ -19,7 +19,7 @@
 
 #include "searchresultjob_p.h"
 #include "job_p.h"
-#include "helper_p.h"
+
 #include "protocolhelper_p.h"
 #include "private/protocol_p.h"
 
@@ -38,7 +38,7 @@ public:
 
     // JobPrivate interface
 public:
-    QString jobDebuggingString() const Q_DECL_OVERRIDE;
+    QString jobDebuggingString() const override;
 };
 
 QString SearchResultJobPrivate::jobDebuggingString() const
@@ -117,12 +117,12 @@ void SearchResultJob::doStart()
     } else {
         scope.setUidSet(d->uid);
     }
-    d->sendCommand(Protocol::SearchResultCommand(d->searchId, d->collection.id(), scope));
+    d->sendCommand(Protocol::SearchResultCommandPtr::create(d->searchId, d->collection.id(), scope));
 }
 
-bool SearchResultJob::doHandleResponse(qint64 tag, const Protocol::Command &response)
+bool SearchResultJob::doHandleResponse(qint64 tag, const Protocol::CommandPtr &response)
 {
-    if (!response.isResponse() || response.type() != Protocol::Command::SearchResult) {
+    if (!response->isResponse() || response->type() != Protocol::Command::SearchResult) {
         return Job::doHandleResponse(tag, response);
     }
 
