@@ -33,14 +33,14 @@ class SessionThread : public QObject
     Q_OBJECT
 
 public:
-    explicit SessionThread(QObject *parent = Q_NULLPTR);
+    explicit SessionThread(QObject *parent = nullptr);
     ~SessionThread();
 
     Connection *createConnection(Connection::ConnectionType connType, const QByteArray &sessionId);
 
 private:
     Q_INVOKABLE Akonadi::Connection *doCreateConnection(Akonadi::Connection::ConnectionType connType,
-                                                        const QByteArray &sessionId);
+            const QByteArray &sessionId);
 
     Q_INVOKABLE void doThreadQuit();
 
@@ -50,5 +50,4 @@ private:
 
 }
 
-
 #endif
