@@ -56,6 +56,11 @@
 #include <QTimer>
 #include <QDBusServiceWatcher>
 
+#ifdef Q_OS_WIN
+#include <windows.h>
+#include <sddl.h>
+#endif
+
 using namespace Akonadi;
 using namespace Akonadi::Server;
 
@@ -76,9 +81,9 @@ AkonadiServer::AkonadiServer(QObject *parent)
     , mAlreadyShutdown(false)
 {
     // Register bunch of useful types
-    qRegisterMetaType<Protocol::Command>();
-    qRegisterMetaType<Protocol::ChangeNotification>();
-    qRegisterMetaType<Protocol::ChangeNotification::List>();
+    qRegisterMetaType<Protocol::CommandPtr>();
+    qRegisterMetaType<Protocol::ChangeNotificationPtr>();
+    qRegisterMetaType<Protocol::ChangeNotificationList>();
     qRegisterMetaType<quintptr>("quintptr");
 }
 
