@@ -23,7 +23,7 @@
 #include "storage/notificationcollector.h"
 #include "tracer.h"
 #include "akonadiserver_debug.h"
-#include "helper_p.h"
+
 
 #include <private/standarddirs_p.h>
 #include <private/xdgbasedirs_p.h>
@@ -112,12 +112,12 @@ void NotificationManager::connectNotificationCollector(NotificationCollector *co
             this, &NotificationManager::slotNotify);
 }
 
-void NotificationManager::slotNotify(const Protocol::ChangeNotification::List &msgs)
+void NotificationManager::slotNotify(const Protocol::ChangeNotificationList &msgs)
 {
     Q_ASSERT(QThread::currentThread() == thread());
 
-    for (const Protocol::ChangeNotification &msg : msgs) {
-        if (msg.type() == Protocol::Command::CollectionChangeNotification) {
+    for (const auto &msg : msgs) {
+        if (msg->type() == Protocol::Command::CollectionChangeNotification) {
             Protocol::CollectionChangeNotification::appendAndCompress(mNotifications, msg);
         } else {
             mNotifications.push_back(msg);
@@ -133,7 +133,7 @@ class NotifyRunnable : public QRunnable
 {
 public:
     explicit NotifyRunnable(NotificationSubscriber *subscriber,
-                            const Protocol::ChangeNotification::List &notifications)
+                            const Protocol::ChangeNotificationList &notifications)
         : mSubscriber(subscriber)
         , mNotifications(notifications)
     {
@@ -143,7 +143,7 @@ public:
     {
     }
 
-    void run() Q_DECL_OVERRIDE {
+    void run() override {
         for (const auto &ntf : qAsConst(mNotifications))
         {
             if (mSubscriber) {
@@ -156,7 +156,7 @@ public:
 
 private:
     QPointer<NotificationSubscriber> mSubscriber;
-    Protocol::ChangeNotification::List mNotifications;
+    Protocol::ChangeNotificationList mNotifications;
 };
 
 void NotificationManager::emitPendingNotifications()
@@ -176,7 +176,7 @@ void NotificationManager::emitPendingNotifications()
         // so that we can work with return value of notify()
         for (const auto &notification : qAsConst(mNotifications)) {
             QVector<QByteArray> listeners;
-            Q_FOREACH (NotificationSubscriber *subscriber, mSubscribers) {
+            for (NotificationSubscriber *subscriber : qAsConst(mSubscribers)) {
                 if (subscriber->notify(notification)) {
                     listeners.push_back(subscriber->subscriber());
                 }
@@ -189,13 +189,13 @@ void NotificationManager::emitPendingNotifications()
     mNotifications.clear();
 }
 
-void NotificationManager::emitDebugNotification(const Protocol::ChangeNotification &ntf,
+void NotificationManager::emitDebugNotification(const Protocol::ChangeNotificationPtr &ntf,
         const QVector<QByteArray> &listeners)
 {
-    Protocol::DebugChangeNotification debugNtf;
-    debugNtf.setNotification(ntf);
-    debugNtf.setListeners(listeners);
-    debugNtf.setTimestamp(QDateTime::currentMSecsSinceEpoch());
+    auto debugNtf = Protocol::DebugChangeNotificationPtr::create();
+    debugNtf->setNotification(ntf);
+    debugNtf->setListeners(listeners);
+    debugNtf->setTimestamp(QDateTime::currentMSecsSinceEpoch());
     for (NotificationSubscriber *subscriber : qAsConst(mSubscribers)) {
         mNotifyThreadPool->start(new NotifyRunnable(subscriber, { debugNtf }));
     }
