@@ -32,7 +32,7 @@
 #include "storage/transaction.h"
 #include "storage/selectquerybuilder.h"
 #include "handler/searchhelper.h"
-#include "helper_p.h"
+
 
 #include <private/xdgbasedirs_p.h>
 #include <private/protocol_p.h>
@@ -342,7 +342,7 @@ void SearchManager::updateSearchImpl(const Collection &collection, QSemaphore *c
     }
 
     // Query all plugins for search results
-    SearchRequest request("searchUpdate-" + QByteArray::number(QDateTime::currentDateTime().toTime_t()));
+    SearchRequest request("searchUpdate-" + QByteArray::number(QDateTime::currentDateTimeUtc().toTime_t()));
     request.setCollections(queryCollections);
     request.setMimeTypes(queryMimeTypes);
     request.setQuery(collection.queryString());
@@ -438,7 +438,7 @@ void SearchManager::searchUpdateResultsAvailable(const QSet<qint64> &results)
     // This will remove IDs that no longer exist in the DB.
     QVariantList newMatchesVariant;
     newMatchesVariant.reserve(newMatches.count());
-    Q_FOREACH (qint64 id, newMatches) {
+    for (qint64 id : qAsConst(newMatches)) {
         newMatchesVariant << id;
     }
 
