@@ -86,7 +86,7 @@ bool DbConfigPostgresql::init(QSettings &settings)
         QDir versionedDir(QStringLiteral("/usr/lib/postgresql"));
         if (versionedDir.exists()) {
             const auto versionedDirs = versionedDir.entryInfoList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name | QDir::Reversed);
-            Q_FOREACH (const auto &path, versionedDirs) {
+            for (const auto &path : versionedDirs) {
                 // Don't break once PostgreSQL 10 is released, but something more future-proof will be needed
                 if (path.fileName().startsWith(QLatin1String("10."))) {
                     postgresVersionedSearchPaths.prepend(path.absoluteFilePath() + QStringLiteral("/bin"));
@@ -336,7 +336,8 @@ void DbConfigPostgresql::stopInternalServer()
     // first, try a FAST shutdown
     execute(mServerPath, { QStringLiteral("stop"),
                            QStringLiteral("--pgdata=%1").arg(mPgData),
-                           QStringLiteral("--mode=fast") });
+                           QStringLiteral("--mode=fast")
+                         });
     if (!checkServerIsRunning()) {
         return;
     }
@@ -344,7 +345,8 @@ void DbConfigPostgresql::stopInternalServer()
     // second, try an IMMEDIATE shutdown
     execute(mServerPath, { QStringLiteral("stop"),
                            QStringLiteral("--pgdata=%1").arg(mPgData),
-                           QStringLiteral("--mode=immediate") });
+                           QStringLiteral("--mode=immediate")
+                         });
     if (!checkServerIsRunning()) {
         return;
     }
@@ -361,7 +363,8 @@ void DbConfigPostgresql::stopInternalServer()
 
         execute(mServerPath, { QStringLiteral("kill"),
                                QStringLiteral("ABRT"),
-                               postmasterPid });
+                               postmasterPid
+                             });
     }
 }
 
