@@ -55,8 +55,8 @@ Q_SIGNALS:
     Q_SCRIPTABLE void done();
 
 protected:
-    void init() Q_DECL_OVERRIDE;
-    void quit() Q_DECL_OVERRIDE;
+    void init() override;
+    void quit() override;
 
 private:
     void inform(const char *msg);
@@ -76,7 +76,7 @@ private:
 
     /**
      * Verifies there is a path from @p col to the root of the collection tree
-     * and that that everything along that path belongs to the same resource.
+     * and that everything along that path belongs to the same resource.
      */
     void checkPathToRoot(const Collection &col);
 
@@ -131,6 +131,12 @@ private:
      */
     void migrateToLevelledCacheHierarchy();
 
+    /**
+     * Check if the search index contains any entries that refer to Akonadi
+     * Items that no longer exist in the DB.
+     */
+    void findOprhanSearchIndexEntries();
+
 private:
     qint64 m_lostFoundCollectionId;
 };
