@@ -25,15 +25,14 @@
 
 #include <QDBusConnection>
 #include <QTimer>
-#include <QCommandLineParser>
 #include <QCoreApplication>
 
 #include <iostream>
 
-AkApplicationBase *AkApplicationBase::sInstance = 0;
+AkApplicationBase *AkApplicationBase::sInstance = nullptr;
 
 AkApplicationBase::AkApplicationBase(int &argc, char **argv, const QLoggingCategory &loggingCategory)
-    : QObject(0)
+    : QObject(nullptr)
     , mArgc(argc)
     , mArgv(argv)
     , mLoggingCategory(loggingCategory)
@@ -86,7 +85,6 @@ void AkApplicationBase::parseCommandLine()
                                            QStringLiteral("Make Akonadi very chatty"));
     mCmdLineParser.addOption(verboseOption);
 
-
     mCmdLineParser.process(QCoreApplication::arguments());
 
     if (mCmdLineParser.isSet(instanceOption)) {
